@@ -1,26 +1,26 @@
 #!/usr/bin/env bash
 
 #############################################################################
-## 
+##
 ##   Logtalk uninstall script
-##   Last updated on October 12, 2023
-## 
-##   This file is part of Logtalk <https://logtalk.org/>  
+##   Last updated on March 22, 2025
+##
+##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
-##   
+##
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
 ##   You may obtain a copy of the License at
-##   
+##
 ##       http://www.apache.org/licenses/LICENSE-2.0
-##   
+##
 ##   Unless required by applicable law or agreed to in writing, software
 ##   distributed under the License is distributed on an "AS IS" BASIS,
 ##   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ##   See the License for the specific language governing permissions and
 ##   limitations under the License.
-## 
+##
 #############################################################################
 
 
@@ -63,6 +63,7 @@ cd "$LOGTALKHOME"/.. || exit 1
 rm -rf "$directory"
 rm -f logtalk
 cd ../bin || exit 1
+rm -f logtalk_setup_env.sh
 rm -f bplgt
 rm -f ciaolgt
 rm -f cxlgt
@@ -111,13 +112,13 @@ rm -f logtalk_tester.1.gz
 rm -f logtalk_doclet.1.gz
 rm -f logtalk_user_setup.1.gz
 rm -f logtalk_version_select.1.gz
-rm -f xvmlgt.1.gz
 rm -f quintuslgt.1.gz
 rm -f sicstuslgt.1.gz
 rm -f swilgt.1.gz
 rm -f taulgt.1.gz
 rm -f tplgt.1.gz
 rm -f xsblgt.1.gz
+rm -f xvmlgt.1.gz
 rm -f yaplgt.1.gz
 cd ../../info || exit 1
 rm -f LogtalkAPIs-$version.info
